==> vtigercrm-5.3.0p0.tgz: modules/MailManager/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'E-Mail Manager',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Bitte warten, Daten werden geladen',
	'JSLBL_Loading'              => 'Laden',
	'JSLBL_Settings'             => 'Einstellungen',
	'JSLBL_Opening'              => 'Öffnen',
	'JSLBL_Deleting'              => 'Löschen',  
	'JSLBL_Updating'             => 'Aktualisieren',
	'JSLBL_Associating'          => 'Zuordnen',
	'JSLBL_Saving_And_Verifying' => 'Speichern & überprüfen',
	'JSLBL_Failed_To_Open_Mail'  => 'Öffnen der E-Mail ist fehlgeschlagen',
	'JSLBL_Finding_Relation'     => 'Beziehung finden',
	'JSLBL_Find_Relation_Now'    => 'Beziehung jetzt finden',
	'JSLBL_Searching'            => 'Suchen',
	'JSLBL_Searching_Please_Wait'=> 'Bitte warten, die Suche läuft',
	'JSLBL_Sending'              => 'Senden',
	'JSLBL_Replied'              => 'Beantwortet',
	'JSLBL_Failed_To_Send_Mail'  => 'Senden der E-Mail ist fehlgeschlagen',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Empfäner darf nicht leer sein',
	'JSLBL_SendWith_EmptySubject'     => 'Möchten Sie diese E-Mail ohne Betreff senden?', 
	'JSLBL_Removing'                  => 'Entfernen',
	'JSLBL_Choose_Server_Type'        => 'Servertyp auswählen',
	'JSLBL_Other'                     => 'Anderer',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Suche nach E-Mail',
	'JSLBL_Nothing_Found'             => 'Nichts gefunden',
	'JSLBL_Delete_Confirm'            =>'Wollen Sie diese E-Mails dauerhaft löschen?',
	'JSLBL_Delete_Mails_Confirm'      =>'Wollen Sie diese E-Mails löschen',
	'JSLBL_Receipents_Warning_Message'=>'Bitte wählen Sie Empfänger aus',
	'JSLBL_NO_MATCH'				  => 'Keine Ergebnisse gefunden',
	'JSLBL_Saving'					=> 'Speichern',
	'JSLBL_Failed_To_Save_Mail'		=>	'Speichern der E-Mail ist fehlgeschlagen',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'Der Anhang konnte nicht entfernt werden',
	'JSLBL_UPLOAD_CANCEL'	=> 'Abbruch',
	'JSLBL_UPLOAD_DROPFILES'=>'Dateien für den Upload bitte hier ablegen',
	'JSLBL_UPLOAD_FILE'=>'Upload',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Fehlgeschlagen',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'Datei-Upload-Limit überschritten!!',
	'JSLBL_MAIL_SENT'=>'Mail wurde verschickt',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Bitte geben Sie eine richtige E-Mail-Adresse ein',
	'JSLBL_Saving'=>'Speichern',
	'JSLBL_SaveWith_EmptySubject'=>'Möchten Sie diese Mail ohne Betreff speichern?',
	'JSLBL_Delete'            =>  'Löschen',
	'JSLBL_Drafts'=>'Entwürfe',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'Passwort darf nicht leer sein',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'Server-Name darf nicht leer sein',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'Benutzername darf nicht leer sein',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'Konto-Name darf nicht leer sein',
	'JSLBL_FROM'=>'Von:',
	'JSLBL_DATE'=>'Datum: ',
	'JSLBL_SUBJECT'=>'Betreff: ',
	'JSLBL_TO'=>'An: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Forwarded message ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Bitte wählen Sie mindestens eine E-Mail aus',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Bitte wählen Sie mindestens eine Aufzeichnung aus',
	'JSLBL_MAIL_MOVED'=>'E-Mails(s) verschoben',
	'JSLBL_MOVING'=>'Verschiebe E-Mail(s)',
	'JSLBL_LOADING_FOLDERS' => 'Ordner laden..',
	'JSLBL_ADD_COMMENT'=>'Kommentar hinzufügen',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Kommentar darf nicht leer sein',
    'JSLBL_NO_EMAILS_SELECTED' => 'Keine E-Mails ausgewählt.',
    'JSLBL_ENTER_SOME_VALUE' => 'Bitte geben Sie einen Suchbegriff ein',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Ihre E-Mail wurde in den Entwürfen gespeichert',
    
	// General translations
	'LBL_Folders'         => 'Ordner',
	'LBL_Newer'           => 'Neuer',
	'LBL_Older'           => 'älter',
	'LBL_No_Mails_Found'  => 'Keine E-Mails gefunden.',
	'LBL_Go_Back'         => 'Zurück',
	'LBL_Reply_All'       => 'Allen antworten',
	'LBL_Reply'           => 'Antworten',
	'LBL_Mark_As_Unread'  => 'Als ungelesen markieren',
	'LBL_Previous'        => 'vorheriges',
	'LBL_Next'            => 'nächstes',
	'LBL_RELATED_RECORDS' => 'bezogene Daten',
	'LBL_Mailbox'         => 'Mailbox',
	'LBL_Outbox'          => 'CRM Ausgang',
	'LBL_Like'            => 'z. B. wie',
	'LBL_Mail_Server'     => 'Name des E-Mail-Server oder IP-Adresse',
	'LBL_Refresh'         => 'Aktualisieren',
	'LBL_Cancel'          => 'Abbruch',
	'LBL_Send'            => 'Senden',
	'LBL_Compose'         => 'Schreiben',
	'LBL_Forward'         => 'Weiterleiten',
	'LBL_Remove'          => 'Entfernen',
	'LBL_Associate'       => 'Verbinden',
	'LBL_Create_Contact'  => 'Kontakt erstellen',
	'LBL_No_Matching_Record_Found' => 'Keine passenden Datensätze gefunden.',
	'LBL_ACTIONS'         => 'Aktionen',
	'LBL_Search'          => 'Suchen',
	'LBL_Delete'            =>  'Löschen',
	
	'LBL_Username'             => 'Benutzername',
	'LBL_Your_Mailbox_Account' => 'Name des E-Mail-Kontos',
	'LBL_Password'             => 'Passwort',
	'LBL_Account_Password'     => 'Passwort des E-Mail-Kontos',
	'LBL_Protocol'    => 'Protokoll',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'SSL Einstellungen',
	'LBL_No_TLS'      => 'kein TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Zertifikat überprüfungen',
	'LBL_Validate_Cert'           => 'überprüfe Zertifikat',
	'LBL_Do_Not_Validate_Cert'    => 'Zertifikat nicht überprüfen',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Kontotyp auswählen',
	
	'LBL_FROM'        => 'Von',
	'LBL_TO'          => 'An',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Datum',
	'LBL_Attachments' => 'Anhänge',
	'LBL_EMAIL_TEMPLATES_LIST'=>'E-Mail-Vorlagen',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'E-Mail-Vorlage auswählen',
	'LBL_ATTACHMENTS'  =>'Anhang:',
	'LBL_SELECT_DOCUMENTS'=>'Dokumente auswählen',
	'LBL_IN' =>'in',
	'LBL_FIND'=>'Finden',
	'LBL_SAVE_NOW'=>'Sofort Speichern',
	'LBL_Drafts'=>'Entwürfe',
 	'LBL_NO_EMAILS_SELECTED' => 'Keine E-Mails ausgewählt.',
	'LBL_SUBJECT'	=>	'Betreff',
	'LBL_WRITE_ACCESS_FOR'	=>'Schreibzugriff für',
	'LBL_READ_ACCESS_FOR'	=>'Lesezugriff für',
	'LBL_MODULE_DENIED' => 'Modul verweigert!',
	'LBL_REFRESH_TIME'=>'Zeit aktualisieren',
	'LBL_NONE' => 'nie',
	'LBL_5_MIN' => 'alle 5 Minuten',
	'LBL_10_MIN' => 'alle 10 Minuten',
	'LBL_MOVE_TO'=>'Verschieben nach...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Kontakt hinzufügen',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Konto hinzufügen',
    'LBL_MAILMANAGER_ADD_Leads' => 'Lead hinzufügen',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Aufgabe hinzufügen',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Ticket hinzufügen',
    'LBL_MAILMANAGER_ADD_Emails' => 'E-Mail anhängen',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Kommentar hinzufügen',
    'LBL_ADD' => 'Hinzufügen',
    'or' => 'oder',
);

?>

==> vtigercrm-5.4.0.tgz: modules/MailManager/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'E-Mail Manager',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Bitte warten, Daten werden geladen',
	'JSLBL_Loading'              => 'Laden',
	'JSLBL_Settings'             => 'Einstellungen',
	'JSLBL_Opening'              => 'Öffnen',
	'JSLBL_Deleting'              => 'Löschen',  
	'JSLBL_Updating'             => 'Aktualisieren',
	'JSLBL_Associating'          => 'Zuordnen',
	'JSLBL_Saving_And_Verifying' => 'Speichern & überprüfen',
	'JSLBL_Failed_To_Open_Mail'  => 'Öffnen der E-Mail ist fehlgeschlagen',
	'JSLBL_Finding_Relation'     => 'Beziehung finden',
	'JSLBL_Find_Relation_Now'    => 'Beziehung jetzt finden',
	'JSLBL_Searching'            => 'Suchen',
	'JSLBL_Searching_Please_Wait'=> 'Bitte warten, die Suche läuft',
	'JSLBL_Sending'              => 'Senden',
	'JSLBL_Replied'              => 'Beantwortet',
	'JSLBL_Failed_To_Send_Mail'  => 'Senden der E-Mail ist fehlgeschlagen',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Empfäner darf nicht leer sein',
	'JSLBL_SendWith_EmptySubject'     => 'Möchten Sie diese E-Mail ohne Betreff senden?', 
	'JSLBL_Removing'                  => 'Entfernen',
	'JSLBL_Choose_Server_Type'        => 'Servertyp auswählen',
	'JSLBL_Other'                     => 'Anderer',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Suche nach E-Mail',
	'JSLBL_Nothing_Found'             => 'Nichts gefunden',
	'JSLBL_Delete_Confirm'            =>'Wollen Sie diese E-Mails dauerhaft löschen?',
	'JSLBL_Delete_Mails_Confirm'      =>'Wollen Sie diese E-Mails löschen',
	'JSLBL_Receipents_Warning_Message'=>'Bitte wählen Sie Empfänger aus',
	'JSLBL_NO_MATCH'				  => 'Keine Ergebnisse gefunden',
	'JSLBL_Saving'					=> 'Speichern',
	'JSLBL_Failed_To_Save_Mail'		=>	'Speichern der E-Mail ist fehlgeschlagen',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'Der Anhang konnte nicht entfernt werden',
	'JSLBL_UPLOAD_CANCEL'	=> 'Abbruch',
	'JSLBL_UPLOAD_DROPFILES'=>'Dateien für den Upload bitte hier ablegen',
	'JSLBL_UPLOAD_FILE'=>'Upload',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Fehlgeschlagen',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'Datei-Upload-Limit überschritten!!',
	'JSLBL_MAIL_SENT'=>'Mail wurde verschickt',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Bitte geben Sie eine richtige E-Mail-Adresse ein',
	'JSLBL_Saving'=>'Speichern',
	'JSLBL_SaveWith_EmptySubject'=>'Möchten Sie diese Mail ohne Betreff speichern?',
	'JSLBL_Delete'            =>  'Löschen',
	'JSLBL_Drafts'=>'Entwürfe',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'Passwort darf nicht leer sein',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'Server-Name darf nicht leer sein',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'Benutzername darf nicht leer sein',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'Konto-Name darf nicht leer sein',
	'JSLBL_FROM'=>'Von:',
	'JSLBL_DATE'=>'Datum: ',
	'JSLBL_SUBJECT'=>'Betreff: ',
	'JSLBL_TO'=>'An: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Forwarded message ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Bitte wählen Sie mindestens eine E-Mail aus',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Bitte wählen Sie mindestens eine Aufzeichnung aus',
	'JSLBL_MAIL_MOVED'=>'E-Mails(s) verschoben',
	'JSLBL_MOVING'=>'Verschiebe E-Mail(s)',
	'JSLBL_LOADING_FOLDERS' => 'Ordner laden..',
	'JSLBL_ADD_COMMENT'=>'Kommentar hinzufügen',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Kommentar darf nicht leer sein',
    'JSLBL_NO_EMAILS_SELECTED' => 'Keine E-Mails ausgewählt.',
    'JSLBL_ENTER_SOME_VALUE' => 'Bitte geben Sie einen Suchbegriff ein',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Ihre E-Mail wurde in den Entwürfen gespeichert',
    
	// General translations
	'LBL_Folders'         => 'Ordner',
	'LBL_Newer'           => 'Neuer',
	'LBL_Older'           => 'älter',
	'LBL_No_Mails_Found'  => 'Keine E-Mails gefunden.',
	'LBL_Go_Back'         => 'Zurück',
	'LBL_Reply_All'       => 'Allen antworten',
	'LBL_Reply'           => 'Antworten',
	'LBL_Mark_As_Unread'  => 'Als ungelesen markieren',
	'LBL_Previous'        => 'vorheriges',
	'LBL_Next'            => 'nächstes',
	'LBL_RELATED_RECORDS' => 'bezogene Daten',
	'LBL_Mailbox'         => 'Mailbox',
	'LBL_Outbox'          => 'CRM Ausgang',
	'LBL_Like'            => 'z. B. wie',
	'LBL_Mail_Server'     => 'Name des E-Mail-Server oder IP-Adresse',
	'LBL_Refresh'         => 'Aktualisieren',
	'LBL_Cancel'          => 'Abbruch',
	'LBL_Send'            => 'Senden',
	'LBL_Compose'         => 'Schreiben',
	'LBL_Forward'         => 'Weiterleiten',
	'LBL_Remove'          => 'Entfernen',
	'LBL_Associate'       => 'Verbinden',
	'LBL_Create_Contact'  => 'Kontakt erstellen',
	'LBL_No_Matching_Record_Found' => 'Keine passenden Datensätze gefunden.',
	'LBL_ACTIONS'         => 'Aktionen',
	'LBL_Search'          => 'Suchen',
	'LBL_Delete'            =>  'Löschen',
	
	'LBL_Username'             => 'Benutzername',
	'LBL_Your_Mailbox_Account' => 'Name des E-Mail-Kontos',
	'LBL_Password'             => 'Passwort',
	'LBL_Account_Password'     => 'Passwort des E-Mail-Kontos',
	'LBL_Protocol'    => 'Protokoll',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'SSL Einstellungen',
	'LBL_No_TLS'      => 'kein TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Zertifikat überprüfungen',
	'LBL_Validate_Cert'           => 'überprüfe Zertifikat',
	'LBL_Do_Not_Validate_Cert'    => 'Zertifikat nicht überprüfen',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Kontotyp auswählen',
	
	'LBL_FROM'        => 'Von',
	'LBL_TO'          => 'An',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Datum',
	'LBL_Attachments' => 'Anhänge',
	'LBL_EMAIL_TEMPLATES_LIST'=>'E-Mail-Vorlagen',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'E-Mail-Vorlage auswählen',
	'LBL_ATTACHMENTS'  =>'Anhang:',
	'LBL_SELECT_DOCUMENTS'=>'Dokumente auswählen',
	'LBL_IN' =>'in',
	'LBL_FIND'=>'Finden',
	'LBL_SAVE_NOW'=>'Sofort Speichern',
	'LBL_Drafts'=>'Entwürfe',
 	'LBL_NO_EMAILS_SELECTED' => 'Keine E-Mails ausgewählt.',
	'LBL_SUBJECT'	=>	'Betreff',
	'LBL_WRITE_ACCESS_FOR'	=>'Schreibzugriff für',
	'LBL_READ_ACCESS_FOR'	=>'Lesezugriff für',
	'LBL_MODULE_DENIED' => 'Modul verweigert!',
	'LBL_REFRESH_TIME'=>'Zeit aktualisieren',
	'LBL_NONE' => 'nie',
	'LBL_5_MIN' => 'alle 5 Minuten',
	'LBL_10_MIN' => 'alle 10 Minuten',
	'LBL_MOVE_TO'=>'Verschieben nach...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Kontakt hinzufügen',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Konto hinzufügen',
    'LBL_MAILMANAGER_ADD_Leads' => 'Lead hinzufügen',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Aufgabe hinzufügen',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Ticket hinzufügen',
    'LBL_MAILMANAGER_ADD_Emails' => 'E-Mail anhängen',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Kommentar hinzufügen',
    'LBL_ADD' => 'Hinzufügen',
	'JSLBL_SendWith_EmptyText' => 'Wollen Sie wirklich eine leere Email versenden?',
	'LBL_ALLMAILS' => 'Alle Emails',
	'LBL_TO_CONTACTS' => 'zu Person',
	'LBL_TO_ACCOUNTS' => 'zu Organisation',
	'LBL_TO_LEADS' => 'zu Lead',
	'LBL_TO_USERS' => 'zu Benutzer',
	'LBL_SENT_MAILS' => 'Sende Emails'
);

?>
